/**
 * 手机前端service层调用接口
 **/
define(function(require,exports,module){
	var appUtils = require("appUtils");
	var gconfig = require("gconfig");
	var global = gconfig.global;
	var service = require("service");
	var serviceSingleton = new service.Service();
	
	/********************************公共代码部分********************************/
    function commonInvoke(paraMap, callback, ctrlParam, reqParamVo){
		reqParamVo.setReqParam(paraMap);
		ctrlParam = ctrlParam?ctrlParam:{};
		reqParamVo.setIsLastReq(ctrlParam.isLastReq);
		reqParamVo.setIsAsync(ctrlParam.isAsync);
		reqParamVo.setIsShowWait(ctrlParam.isShowWait);
		reqParamVo.setTimeOutFunc(ctrlParam.timeOutFunc);
		reqParamVo.setIsShowOverLay(ctrlParam.isShowOverLay);
		reqParamVo.setTipsWords(ctrlParam.tipsWords);
		reqParamVo.setDataType(ctrlParam.dataType);
		reqParamVo.setIsGlobal(ctrlParam.isGlobal);
		reqParamVo.setProtocol(ctrlParam.protocol);
		serviceSingleton.invoke(reqParamVo, callback);
	}
	function destroy(){
		serviceSingleton.destroy();
	}
	var mobileService = { //对应的接口方法需要在这里暴露出来
		"getInstance": getInstance, //为了避免以前调用getInstance方法报错
		"destroy": destroy
	};

	/* 获取用户手机号码 */
	function getPhone(){
		var phone = "";
		if(global.phone){
			phone = global.phone;
		}else{
			// 获取壳子里的手机号
			var key = {key : "phone"};
//			phone = require("external").callFunction("55601",JSON.stringify(key));
			global.phone = phone;
		}
		return phone;
	}

	function getInstance(){
		return mobileService;
	}
	module.exports = mobileService;
	
	/********************************应用接口开始********************************/
	/**
	 * 接口方法模板
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.submitPhoto = function(param,callback,ctrlParam) 
    {
	    var paraMap = {};
		paraMap["funcNo"] = "501503";
		paraMap["user_id"] = param.user_id;
		
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }

	/**
	 * @author 赵焕丛
	 * 功能：获取股票信息
	 * 参数: callBackFunc:回调函数
	 */
	mobileService.getStockInfo = function(param,callBackFunc,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1002004";
		paraMap["trd_code"] = param.trd_code;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.cfserverPath);
		reqParamVo.setReqParam(paraMap);
		commonInvoke(paraMap,callBackFunc,ctrlParam,reqParamVo);
	};
	
	
	/**
	 * @author 焕丛
	 * 功能：获取catalog_id
	 * 参数: callBackFunc:回调函数
	 */
	mobileService.getTitle = function(param,callBackFunc,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1002003";
		paraMap["parent_id"] = param.parent_id;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.cfserverPath);
		reqParamVo.setReqParam(paraMap);
		commonInvoke(paraMap,callBackFunc,ctrlParam,reqParamVo);
	};
	
	/**
	 * @author 焕丛
	 * 功能：获取文章内容
	 * 参数: callBackFunc:回调函数
	 */
	mobileService.getContent = function(param,callBackF,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1002002";
		paraMap["article_id"] = param.article_id;
		var reqParamVo =new service.ReqParamVo();
		reqParamVo.setUrl(global.cfserverPath);
		reqParamVo.setReqParam(paraMap);
		commonInvoke(paraMap,callBackF,ctrlParam,reqParamVo);
	};	
	

	
	/**
	 * @author 焕丛
	 * 功能：获取标题
	 * 入参: catalog_id,page,pageSize
	 * 回参:title,article_id,create_date
	 */
	mobileService.testTitle = function(param,callBackFun,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1002001";
		paraMap["page"] = param.page;
		paraMap["pageSize"] = param.pageSize;
		paraMap["catalog_id"] = param.catalog_id;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.cfserverPath);
		reqParamVo.setReqParam(paraMap);
		commonInvoke(paraMap,callBackFun,ctrlParam,reqParamVo);
	};	
    

	/**
	 * 更新版本(1002000)
	 * @Author:柴登峰
	 * @param versionsn  版本号
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.getVersion = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1002000";
		paraMap["versionsn"] = param.versionsn;
		paraMap["chancel"] = param.chancel;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 查找订单失败原因(1000235)
	 * @Author:柴登峰
	 * @param order_id 订单ID
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.orderErrMsg = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1000235";
		paraMap["order_id"] = param.order_id;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 检验身份证号码是否开过户(1000201)
	 * @Author:柴登峰
	 * @param validate_condition 身份证号码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.checkCardId = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1000201";
		paraMap["validate_condition"] = param.cardId;
		paraMap["validate_type"] = "9";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 检查身份证号是否已被使用
	 * @param user_name 用户编号
	 * @param id_kind 证件类型
	 * @param id_no 证件号码
	 * @param mobile_phone 手机号码
	 * @param type 检查类型
	 * @memberOf {TypeName}
	 */
	mobileService.checkCard = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1001704";
		paraMap["user_name"] = param.user_name;
		paraMap["id_kind"] = param.id_kind;
		paraMap["id_no"] = param.id_no;
		paraMap["mobile_phone"] = param.mobile_phone;
		paraMap["type"] = param.type;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 绑定资金账号(1001120)
	 * @Author:柴登峰
	 * @param fund_account 资金账号
	 * @param user_id 用户ID
	 * @param trade_pwd 支付密码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.bindAccount = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1001120";
		paraMap["fund_account"] = param.fund_account;
		paraMap["user_id"] = param.user_id;
		paraMap["trade_pwd"] = param.trade_pwd;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 商城账号用户登入(1000207)
	 * @Author:黎志勇
	 * @param login_value 登录值
	 * @param type类型：1 账户名,2 手机,3 邮箱,7 身份证
	 * @param login_pwd 登录密码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.userLogin = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000207";
		paraMap["login_value"] = param.login_value;
		paraMap["type"] = "1";
		paraMap["login_pwd"] = param.login_pwd;
		paraMap["ticket"] = param.vf_code;
		/*paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";*/

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * 商城账号用户注册(1000204)
	 * @param mobile_phone 手机号码
	 * @param login_pwd 登录密码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.register = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000204";
		paraMap["mobile_phone"] = param.mobile;
		paraMap["login_pwd"] = param.login_pwd;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 查询用户银行信息
	 * @param user_id 用户ID
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 * @memberOf {TypeName}
	 */
	mobileService.bankInfo = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1000377";
		paraMap["user_id"] = param.user_id;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 查询支持的银行信息
	 * @param {Object} param
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 * @memberOf {TypeName}
	 */
	mobileService.supportBank = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1001700";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * 提交银行信息
	 * @param user_id 用户ID
	 * @param bank_no 银行编号
	 * @param bank_pwd 银行密码
	 * @param bank_card 银行卡号
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 * @memberOf {TypeName}
	 */
	mobileService.updateBankInfo = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1000376";
		paraMap["user_id"] = param.user_id;
		paraMap["bank_no"] = param.bank_no;
		paraMap["bank_pwd"] = param.bank_pwd;
		paraMap["bank_card"] = param.bank_card;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 获取协议内容
	 * @param agreement_id
	  * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 * @memberOf {TypeName}
	 */
	mobileService.getContractContent = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1000307";
		paraMap["agreement_id"] = param.agreement_id;
		paraMap["agreement_type"] = param.agreement_type;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/*
	 * 查询绑定银行错误信息
	 */
	mobileService.queryBankErr = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1000379";
		paraMap["user_id"] = param.user_id;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/*
	 * 校验手机号码是否已存在
	 */
 //	MobileService.prototype.checkMobileIsExists= function(param,callback,isLastReq,isShowWait,timeOutFunc){
 //		var paraMap = {};
 //		paraMap["funcNo"] = "1001704";
 //		paraMap["user_name"] = param.user_name;
 //		paraMap["id_no"] = param.id_no;
 //		paraMap["mobile_phone"] = param.mobile;
 //		paraMap["type"] = param.type;
 //		var reqParamVo = $.getReqParamVo();
 //		reqParamVo.setUrl(global.serverPath);
 //		reqParamVo.setReqParam(paraMap);
 //		reqParamVo.setIsLastReq((typeof(isLastReq)=="undefined"||isLastReq==="")?true:isLastReq);
 //		reqParamVo.setIsShowWait((typeof(isShowWait)=="undefined"||isShowWait==="")?true:isShowWait);
 //		reqParamVo.setTimeOutFunc(timeOutFunc);
 //		this.service.invoke(reqParamVo,callback);
 //	};

	/*
	 * 开通手机登陆
	 */
	mobileService.connectMobile = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1000361";
		paraMap["user_id"] = param.user_id;
		paraMap["login_pwd"] = param.login_pwd;
		paraMap["mobile_phone"] = param.mobile_phone;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/*
	 * 手机验证码正确与否
	 */
	mobileService.checkMobileCode = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "120027";
		paraMap["verify_code"] = param.verify_code;
 //		paraMap["resp_url"] = param.resp_url;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/*
	 * 向手机发送验证码
	 */
	mobileService.sendMobileCode = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "120026";
		paraMap["client_name"] = param.client_name;
		paraMap["id_no"] = param.id_no;
		paraMap["bank_no"] = param.bank_no;
		paraMap["bank_account"] = param.bank_account;
		paraMap["mobile_phone"] = param.mobile_phone;
		paraMap["req_trace_num"] = param.req_trace_num;
 //		paraMap["resp_url"] = param.resp_url;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	 /**
	 * 忘记密码，重置密码
	 * @param funcNo服务号 1000378
	 * @param login_pwd	       char	Y	新登录密码
	 * @param login_pwd_second char	Y	确认新登录密码
	 * @param mobile_phone     char	Y	手机号码
	 * @param callback 回调函数
	 *
	 */
	mobileService.resetPassword = function (param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1000378";
		paraMap["login_pwd"] = param.new1_pwd;
		paraMap["login_pwd_second"] = param.new2_pwd;
		paraMap["mobile_phone"] = param.mobile_phone;
		paraMap["card_no"] = param.card_no;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * 资金账号用户登入(1000207)
	 * @param mobile_phone 手机号码
	 * @param trade_pwd 交易密码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.fundLogin = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = param.funcNo;
		if(param.loginType=="1"){
			paraMap["fund_account"] = param.fund_account;
			paraMap["password"] = param.password;
		}else{
			paraMap["login_account"] = param.login_account;
			paraMap["trade_pwd"] = param.trade_pwd;
		}
		/*paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";*/

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 功能: 商城落地资金账号登录的资料
	 * 入参: callBackFunc: 回调函数
	 *       login_id：资金账号
	 *       login_pwd：交易密码
	 */

	mobileService.savaZjzhInfo = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1001103";
		paraMap["fidKhh"] = param.fidKhh;
		paraMap["fidKhqz"] = param.fidKhqz;
		paraMap["fidYyb"] = param.fidYyb;
		paraMap["fidXtcsbz"] = param.fidXtcsbz;
		paraMap["fidKhxm"] = param.fidKhxm;
		paraMap["fidKhzt"] = param.fidKhzt;
		paraMap["fidTzzfl"] = param.fidTzzfl;
		paraMap["fund_account"] = param.fund_account;
		paraMap["trade_pwd"] = param.trade_pwd;

		paraMap["FID_ZJBH"] = param.FID_ZJBH;
		paraMap["FID_MOBILE"] = param.FID_MOBILE;
		paraMap["FID_EMAIL"] = param.FID_EMAIL;
		paraMap["FID_FAX"] = param.FID_FAX;
		paraMap["FID_DH"] = param.FID_DH;
		paraMap["FID_DZ"] = param.FID_DZ;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};

	/**
	 * 确认支付密码(1001103)
	 * @param fund_account 资金账号
	 * @param login_pwd 支付密码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.payPwd = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001103";
		if(validata.isEmpty(param.fund_account)){
			paraMap["mobile_phone"] = param.mobile_phone;
		}else{
			paraMap["fund_account"] = param.fund_account;
		}
		paraMap["login_pwd"] = param.pay_pwd;
		paraMap["login_type"] = param.login_type;
		/*paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";*/

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 查询图片信息(1000311)
	 * @Author:黎志勇
	 * @param img_class   图片所属分类
	 * @param img_type 图片类别
	 * @param img_vesting 图片归属
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.showPic = function showPic(param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000311";
		paraMap["img_class"] = param.img_class;
		paraMap["img_type"] = param.img_type;
		paraMap["img_vesting"] = param.img_vesting;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 查询用户存管信息(1001111)
	 * @Author:黎志勇
	 * @param fund_account   资金账号
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.accountBank = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001111";
		paraMap["fund_account"] = param.fund_account;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * 用户关注查询(1000260)
	 * @param user_id 用户编号
	 * @param product_sub_type产品类别
	 * @param page 当前页数
	 * @param numPerPage 单页显示记录数
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.queryMyAttention = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000260";
		paraMap["user_id"] = param.user_id;
		paraMap["product_sub_type"] = param.product_sub_type;
		paraMap["page"] = param.page;
		paraMap["numPerPage"] = param.numPerPage;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * 用户订单查询(1000238)
	 * @param user_id 用户编号
	 * @param product_sub_type产品类别
	 * @param page 当前页数
	 * @param numPerPage 单页显示记录数
	 * @param flag	1保证金2手机账户
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.queryMyOrder = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000238";
		paraMap["user_id"] = param.user_id;
		//paraMap["product_sub_type"] = param.product_sub_type;
		paraMap["page"] = param.page;
		paraMap["product_id"] = param.product_id;
		paraMap["numPerPage"] = param.numPerPage;
		paraMap["end_time"] = param.end_time;
		paraMap["start_time"] = param.start_time;
		paraMap["order_state"] = param.order_state;
		paraMap["flag"] = param.flag;
		paraMap["phone"] = getPhone();
		//paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * 用户订单查询(1000239)
	 * @param user_id 用户编号
	 * @param product_sub_type产品类别
	 * @param page 当前页数
	 * @param numPerPage 单页显示记录数
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.queryUserOrder = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000239";
		paraMap["user_id"] = param.user_id;
		paraMap["product_sub_type"] = param.product_sub_type;
		paraMap["order_state"] = param.order_state;
		paraMap["page"] = param.page;
		paraMap["numPerPage"] = param.numPerPage;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * 查询份额(1001609)
	 * @param fund_account 资金账号
	 * @param product_sub_type 产品类别
	 * @param page 当前页数
	 * @param numPerPage 单页显示记录数
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.queryShare = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001609";
		paraMap["product_sub_type"] = param.product_sub_type;
		paraMap["page"] = param.page;
		paraMap["numPerPage"] = param.numPerPage;
		paraMap["fina_belongs"] = param.fina_belongs;
		paraMap["source"] = param.source;
		paraMap["client_id"] = param.client_no;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * 订单撤销(1000250)
	 * @param old_order_id 原订单编号
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.undoOrder = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000250";
		paraMap["userId"] = param.user_id;
		paraMap["old_order_id"] = param.old_order_id;
		paraMap["trade_pwd"] = param.trade_pwd;
		paraMap["loginFlag"] = param.loginFlag;
		paraMap["app_timestamp"] = param.app_timestamp;
		paraMap["apply_no"] = param.apply_no;
		paraMap["trd_date"] = param.trd_date;
		paraMap["fund_account"] = param.fund_account;
		paraMap["khh"] = param.khh;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * 取消订单(1000251)
	 * @param old_order_id 原订单编号
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.cancelOrder = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000251";
		paraMap["old_order_id"] = param.old_order_id;
		paraMap["product_sub_type"] = param.product_sub_type;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * 赎回(1000252)
	 * @param product_id 产品编号
	 * @param user_id 用户编号
	 * @param order_quantity 赎回份额
	 * @param order_channel 订单渠道
	 * @param money_type 币种
	 * @param trade_pwd 交易密码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.redemption = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000252";
		paraMap["product_id"] = param.product_id;
		paraMap["user_id"] = param.user_id;
		paraMap["order_quantity"] = param.order_quantity;
		paraMap["order_channel"] = param.order_channel;
		paraMap["money_type"] = param.money_type;
		paraMap["trade_pwd"] = param.trade_pwd;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * 查询资金(1001113)
	 * @param fund_account   资金账号
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.queryAsset = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001113";
		paraMap["fund_account"] = param.fund_account;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 获取用户风险评测试题(1000303)
	 * @Author:黎志勇
	 * @param risk_type_id 试题类号
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.queryEval = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000303";
		paraMap["risk_type_id"] = param.risk_type_id;
		paraMap["cpjg"] = param.cpjg;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 提交风险测评(1000304)
	 * @Author:黎志勇
	 * @param user_id 用户编号
	 * @param risk_type_id 试题类号
	 * @param content 提交数据
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.submitTestAnswerPhone = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000304";
		paraMap["user_id"] = param.user_id;
		paraMap["risk_type_id"] = param.risk_type_id;
		paraMap["content"] = param.content;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};

	/**
	 * 查询银证转账流水(1001108)
	 * @Author:黎志勇
	 * @param fund_account   资金账号
	 * @param page 当前页数
	 * @param numPerPage 单页显示记录数
	 * @param trans_type 转账类别
	 * 	@param bank_no   银行编号
	 * @param money_type 币种
	 * @param start_date 开始日期
	 * @param end_date 结束日期
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.changeQuery = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001108";
		paraMap["fund_account"] = param.fund_account;
		paraMap["page"] = param.page;
		paraMap["numPerPage"] = param.numPerPage;
		paraMap["trans_type"] = param.trans_type;
		paraMap["bank_no"] = param.bank_no;
		paraMap["money_type"] = param.money_type;
		paraMap["start_date"] = param.start_date;
		paraMap["end_date"] = param.end_date;
		paraMap["min_money"] = param.min_money;
		paraMap["max_money"] = param.max_money;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 银证转账(1001107)
	 * @Author:黎志勇
	 * @param fund_account   资金账号
	 * @param trans_type 转账类别
	 * 	@param bank_no   银行编号
	 * @param fund_amount 转账金额
	 * @param fund_pwd 资金密码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.bankTrans = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001107";
		paraMap["fund_account"] = param.fund_account;
		paraMap["trans_type"] = param.trans_type;
		paraMap["bank_no"] = param.bank_no;
		paraMap["fund_amount"] = param.fund_amount;
		paraMap["fund_pwd"] = param.fund_pwd;
		paraMap["trade_pwd"] = param.trade_pwd;
		paraMap["bank_pwd"] = param.bank_pwd;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 查询用户状态(1001720)
	 * @param mobile_phone 手机号码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.queryUserState = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001720";
		paraMap["mobile_phone"] = param.mobile_phone;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 修改用户信息(1000205)
	 * @Author:黎志勇
	 * @param user_id   用户编号
	 * @param user_name 用户姓名
	 * @param nick_name 用户昵称
	 * @param gender   性别
	 * @param birthday  生日
	 * @param identity_type 证件类型
	 * @param identity_num  证件号码
	 * @param mobile_phone 手机号码
	 * @param user_mail 邮箱
	 * @param telephone   固定电话
	 * @param address  通信地址
	 * @param post_code 邮编
	 * @param qq_microblog   QQ微博
	 * @param qq_microblog_uid QQ微博UID
	 * @param sina_microblog 新浪微博账号
	 * @param sina_microblog_uid   新浪微博UID
	 * @param qq  QQ号
	 * @param qq_uid QQ_UID
	 * @param wechat  微信
	 * @param weixin_uid 微信UID
	 * @param update_time  信息更新时间
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.submitInfo = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000205";
 //		paraMap["user_id"] = param.user_id;
 //		paraMap["user_name"] = param.user_name;
 //		paraMap["nick_name"] = param.nick_name;
 //		paraMap["gender"] = param.gender;
 //		paraMap["birthday"] = param.birthday;
 //		paraMap["identity_type"] = param.identity_type;
 //		paraMap["identity_num"] = param.identity_num;
 //		paraMap["mobile_phone"] = param.mobile_phone;
 //		paraMap["user_mail"] = param.user_mail;
 //		paraMap["address"] = param.address;
 //		paraMap["telephone"] = param.telephone;
 //		paraMap["post_code"] = param.post_code;
 //		paraMap["qq_microblog"] = param.qq_microblog;
 //		paraMap["qq_microblog_uid"] = param.qq_microblog_uid;
 //		paraMap["sina_microblog"] = param.sina_microblog;
 //		paraMap["sina_microblog_uid"] = param.sina_microblog_uid;
 //		paraMap["qq"] = param.qq;
 //		paraMap["qq_uid"] = param.qq_uid;
 //		paraMap["wechat"] = param.wechat;
 //		paraMap["weixin_uid"] = param.weixin_uid;
 //		paraMap["update_time"] = param.update_time;
		/*paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";*/
		 paraMap["user_id"] = param.user_id ;
		 paraMap["user_name"] = param.user_name ;
		 paraMap["identity_num"] = param.identity_num ;
		 paraMap["birthday"] = param.birthday ;
		 paraMap["gender"] = param.gender ;
		 paraMap["mobile_phone"] = param.mobile_phone ;
		 paraMap["user_mail"] = param.user_mail ;
		 paraMap["address"] = param.address ;
		 paraMap["post_code"] = param.post_code ;
		 paraMap["telephone"] = param.telephone ;
		 paraMap["qq_microblog"] = param.qq_microblog ;
		 paraMap["sina_microblog"] = param.sina_microblog ;
		 paraMap["qq"] = param.qq ;
		 paraMap["wechat"] = param.wechat;
		 paraMap["id_iss_agcy"] = param.id_iss_agcy;
		 paraMap["id_beg_date"] = param.id_beg_date ;
		 paraMap["id_exp_date"] = param.id_exp_date ;

		 var reqParamVo = new service.ReqParamVo();
		 reqParamVo.setUrl(global.serverPath);
		 commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title 查询理财产品信息(分页列表)(1000240)
	 * @param product_shelf :上架状态
	 * @param page：当前页数
	 * @param numPerPage ：单页显示记录数
	 * @param recommend_type :推荐属性   1首页推荐 2购买推荐
	 * @param fina_type：理财分类  0低风险  1高风险  2理财类  3混合型  4现金类
	 * @param is_hot_sale 是否按照热销排序  1排序 0或其他不排
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.findFinan = function (param,callback,ctrlParam)
	{
		var paraMap ={};
		paraMap["funcNo"]="1000240";
		paraMap["product_shelf"]=param.product_shelf;
		paraMap["page"]=param.page;
		paraMap["numPerPage"]=param.numPerPage;
		paraMap["recommend_type"]=param.recommend_type;
		paraMap["fina_belongs"]=param.fina_belongs;
		paraMap["is_hot_sale"]=param.is_hot_sale;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title 查询基金产品信息(分页列表)(1000241)
	 * @param product_shelf :上架状态
	 * @param comp_ecommend_type:组合产品推荐  1 进取型组合推荐 2 保守型组合推荐 3 稳定型组合推荐
	 * @param recommend_type :推荐属性   1首页推荐 2购买推荐
	 * @param fund_type：基金类型
	 * @param register_corp_code :基金公司
	 * @param risk_level: 风险等级
	 * @param amount : 基金规模
	 * @param create_time : 成立时间  时间格式yyyy-MM-dd
	 * @param page：当前页数
	 * @param numPerPage ：单页显示记录数
	 * @param is_hot_sale 是否按照热销排序  1排序 0或其他不排
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.findFund = function (param,callback,ctrlParam)
	{
		var paraMap ={};
		paraMap["funcNo"]="1000241";
		paraMap["comp_ecommend_type"]=param.comp_ecommend_type;
		paraMap["recommend_type"]=param.recommend_type;
		paraMap["fund_type"]=param.fund_type;
		paraMap["register_corp_code"]=param.register_corp_code;
		paraMap["risk_level"]=param.risk_level;
		paraMap["amount"]=param.amount;
		paraMap["create_time"]=param.create_time;
		paraMap["is_nav"]=param.is_nav;
		paraMap["performance_sort"]=param.performance_sort;
		paraMap["product_performance"]=param.product_performance;
		paraMap["page"]=param.page;
		paraMap["numPerPage"]=param.numPerPage;
		paraMap["is_hot_sale"]=param.is_hot_sale;
		paraMap["product_shelf"]=param.product_shelf;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};

	/**
	 * @Author:龙沅文
	 * @Title 查询咨询产品信息(分页列表)(1000242)
	 * @param product_shelf :上架状态
	 * @param page：当前页数
	 * @param numPerPage ：单页显示记录数
	 * @param recommend_type :推荐属性   1首页推荐 2购买推荐
	 * @param brand_id :品牌编号
	 * @param is_hot_sale 是否按照热销排序  1排序 0或其他不排
	 * @param info_type 资讯产品类别
	 * @param father_product_id 父产品编号
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.findInfo = function (param,callback,ctrlParam)
	{
		var paraMap ={};
		paraMap["funcNo"]="1000242";
		paraMap["product_shelf"]=param.product_shelf;
		paraMap["page"]=param.page;
		paraMap["numPerPage"]=param.numPerPage;
		paraMap["recommend_type"]=param.recommend_type;
		paraMap["brand_id"]=param.brand_id;
		paraMap["is_hot_sale"]=param.is_hot_sale;
		paraMap["info_type"]=param.info_type;
		paraMap["father_product_id"]=param.father_product_id;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};

	/**
	 * @Author:黎志勇
	 * @Title 查询服务产品信息(分页列表)(1000249)
	 * @param product_shelf :上架状态
	 * @param page：当前页数
	 * @param numPerPage ：单页显示记录数
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.findService = function (param,callback,ctrlParam)
	{
		var paraMap ={};
		paraMap["funcNo"]="1000249";
		paraMap["product_shelf"]=param.product_shelf;
		paraMap["page"]=param.page;
		paraMap["numPerPage"]=param.numPerPage;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title 查询服务产品信息(分页列表)(1000249)
	 * @param product_shelf :上架状态
	 * @param page：当前页数
	 * @param numPerPage ：单页显示记录数
	 * @param recommend_type :推荐属性   1首页推荐 2购买推荐
	 * @param is_hot_sale 是否按照热销排序  1排序 0或其他不排
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.findServ = function (param,callback,ctrlParam)
	{
		var paraMap ={};
		paraMap["funcNo"]="1000249";
		paraMap["product_shelf"]=param.product_shelf;
		paraMap["page"]=param.page;
		paraMap["numPerPage"]=param.numPerPage;
		paraMap["recommend_type"]=param.recommend_type;
		paraMap["is_hot_sale"]=param.is_hot_sale;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};


	/**
	 * @Author:龙沅文
	 * @Title 查询理财产品信息(单个)(1000243)
	 * @param product_id 产品编号
	 * @param product_sub_type

	 */
	mobileService.finanInfo = function (param,callback,ctrlParam)
	{
		var paraMap ={};
		paraMap["funcNo"]="1000243";
		paraMap["product_id"]=param.product_id;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		// paraMap["product_sub_type"]=param.product_sub_type;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};


	/**
	 * @Author:龙沅文
	 * @Title 查询基金产品信息(单个)(1000244)
	 * @param product_id 产品编号
	 */
	mobileService.fundInfo = function (param,callback,ctrlParam)
	{
		var paraMap ={};
		paraMap["funcNo"]="1000244";
		paraMap["product_id"]=param.product_id;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title 查询服务产品信息(单个)(1000248)
	 * @param product_id   产品编号
	 * @param rules_id     规则编号
	 * @param service_type 服务方式
	 */
	mobileService.findServInfo = function (param,callback,ctrlParam)
	{
		var paraMap ={};
		paraMap["funcNo"]="1000248";
		paraMap["product_id"]=param.product_id;
		paraMap["rules_id"]=param.rules_id;
		paraMap["service_type"]=param.service_type;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};

	/**
	 * @Author:龙沅文
	 * @Title 查询咨询产品信息(单个)(1000245)
	 * @param product_id   产品编号
	 * @param rules_id     规则编号
	 * @param service_type 服务方式
	 */
	mobileService.findInfoDetail = function (param,callback,ctrlParam)
	{
		var paraMap ={};
		paraMap["funcNo"]="1000245";
		paraMap["product_id"]=param.product_id;
		paraMap["rules_id"]=param.rules_id;
		paraMap["service_type"]=param.service_type;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};


	/**
	 * @Author:龙沅文
	 * @Title 查询价格规则和服务方式(1000247)(非金融产品)
	 * @param product_id   产品编号
	 */
	mobileService.findPriceRule = function (param,callback,ctrlParam)
	{

		var paraMap ={};
		paraMap["funcNo"]="1000247";
		paraMap["product_id"]=param.product_id;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);


	};

	/**
	 * @Author:龙沅文
	 * @Title 新增关注(1000261)
	 * @param user_id   用户编号
	 * @param product_sub_type 产品类别
	 * @param product_id  产品编号
	 */
	mobileService.addAttention = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000261";
		paraMap["user_id"] = param.user_id;
		paraMap["product_sub_type"] = param.product_sub_type;
		paraMap["product_id"] = param.product_id;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};


	/**
	 * @Author:龙沅文
	 * @Title 取消关注(1000262)
	 * @param user_id  用户编号
	 * @param product_id 产品编号
	 */
	mobileService.cancerAttention = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000262";
		paraMap["user_id"] = param.user_id;
		paraMap["product_id"] = param.product_id;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};



	/**
	 * @Author:龙沅文
	 * @Title 用户关注查询(1000260)
	 * @param user_id  用户编号
	 * @param product_sub_type  产品类别
	 * @param page  当前页
	 * @param numPerPage  每页显示多少条数据
	 *
	 */
	mobileService.userAttentionFind = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000260";
		paraMap["user_id"] = param.user_id;
		paraMap["product_sub_type"] = param.product_sub_type;
		paraMap["page"] = param.page;
		paraMap["numPerPage"] = param.numPerPage;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};


	/**
	 * @Author:龙沅文
	 * @Title 理财购买(1000232)
	 * @param product_id 产品编号
	 * @param user_id  用户编号
	 * @param tot_price 购买金额
	 */
	mobileService.finanPuy = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000232";
		paraMap["source"] = param.source;
		paraMap["client_no"] = param.client_no;
		paraMap["trade_pwd"] = param.trade_pwd;
		paraMap["product_id"] = param.product_id;
		paraMap["user_id"] = param.user_id;
		paraMap["tot_price"] = param.tot_price;
		paraMap["order_channel"] = param.order_channel;
		paraMap["fund_account"] = param.fund_account;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};

	/**
	 * @Author:龙沅文
	 * @Title 基金购买(1000231)
	 * @param product_id 产品编号
	 * @param user_id  用户编号
	 * @param tot_price 购买金额
	 */
	mobileService.fundPuy = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000231";
		paraMap["product_id"] = param.product_id;
		paraMap["user_id"] = param.user_id;
		paraMap["tot_price"] = param.tot_price;
		paraMap["order_channel"] = param.order_channel;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};

	/**
	 * @Author:龙沅文
	 * @Title 支付订单 (1000234)(金融产品)
	 * @param order_id 订单编号
	 * @param fund_account  资金账号
	 * @param trade_pwd   交易密码
	 */
	mobileService.orderPayment = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000234";
		paraMap["order_id"] = param.order_id;
		paraMap["user_id"] = param.user_id;
		paraMap["pay_account"] = param.pay_account;
		paraMap["trade_pwd"] = param.trade_pwd;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title 支付订单 (1000257)(非金融产品)  注:后期可能后修改
	 * @param order_id 		订单编号
	 * @param fund_account  资金账号
	 * @param trade_pwd     交易密码
	 */
	mobileService.orderOtherPayment = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000257";
		paraMap["order_id"] = param.order_id;
		paraMap["fund_account"] = param.fund_account;
		paraMap["trade_pwd"] = param.trade_pwd;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};

	/**
	 * @Author:龙沅文:
	 * @Title 金融订单查询(1000236)
	 * @param user_id:用户id
	 * @param order_id：订单id
	 * @param product_sub_type：产品类别
	 */
	mobileService.getFinancialOrder = function (param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1000236";
		paraMap["user_id"] =param.user_id;
		paraMap["order_id"] =param. order_id;
		paraMap["product_sub_type"] = param.product_sub_type; //可不传
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文:
	 * @Title 非金融订单查询(1000237)
	 * @param user_id:用户id
	 * @param order_id：订单id
	 * @param product_sub_type：产品类别
	 */
	mobileService.getOtherOrder = function (param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1000237";
		paraMap["user_id"] =param.user_id;
		paraMap["order_id"] =param. order_id;
		paraMap["product_sub_type"] = param.product_sub_type;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title 查询签署(1000305)(金融产品，非金融产品)   注：两类产品调同一接口，只需根据传入的产品编号（product_id）查询出不同的协议
	 * @param product_id 产品编号
	 * @param user_id  用户编号
	 */
	mobileService.findAgreement = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000305";
		paraMap["product_id"] = param.product_id;
		paraMap["user_id"] = param.user_id;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};

	/**
	 * @Author:龙沅文
	 * @Title 签署协议(1000306)(金融产品)
	 * @param product_id 产品编号
	 * @param agreement_id  协议编号
	 * @param user_id  用户编号
	 */
	mobileService.signAgreement = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000306";
		paraMap["product_id"] = param.product_id;
		paraMap["user_id"] = param.user_id;
		paraMap["agreement_id"] = param.agreement_id;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};



	/**
	 * @Author:龙沅文
	 * @Title 判断协议是否签署(1000305)(非金融产品)
	 * @param product_id 产品编号
	 * @param user_id  用户编号
	 */
	mobileService.isAgreement = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000305";
		paraMap["product_id"] = param.product_id;
		paraMap["user_id"] = param.user_id;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};

	/**
	 * @Author:龙沅文
	 * @Title 签署协议(1000306)(非金融产品)
	 * @param product_id 产品编号
	 * @param product_sub_type  产品类型
	 * @param user_id  用户编号
	 */
	mobileService.signOtherAgreement = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000306";

		paraMap["product_id"] = param.product_id;
		paraMap["user_id"] = param.user_id;
		paraMap["product_sub_type"] = param.product_sub_type;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};


	/**
	 * 查询理财产品信息(1000240)分页
	 * @param product_shelf   上架状态
	 * @param page 当前页数
	 * @param numPerPage 单页显示记录数
	 * @param recommend_type   推荐属性(1首页推荐 2购买推荐 )
	 * @param fina_type  理财分类( 0低风险  1高风险  2理财类  3混合型  4现金类 )
	 * @param is_hot_sale 是否按照热销排序 1排序 0或其他不排（按照销量排序  热销推荐）
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.getFinancialProduct = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000240";
		paraMap["product_shelf"] = param.product_shelf;
		paraMap["page"] = param.page;
		paraMap["numPerPage"] = param.numPerPage;
		paraMap["recommend_type"] = param.recommend_type;
		paraMap["fina_type"] = param.fina_type;
		paraMap["is_hot_sale"] = param.is_hot_sale;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};


	/**
	 * @Author:龙沅文
	 * @Title 银行理财产品判断是否是首次购买(1001900)
	 * @param fund_account 资金账号
	 * @param product_id 产品编号
	 * @param product_code 产品代码
	 * @param product_sub_type 产品类型
	 */
	mobileService.isFirstBuyFinan = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001900";
		paraMap["product_id"] = param.product_id;
		paraMap["fund_account"] = param.fund_account;
		paraMap["product_code"]=param.product_code;
		paraMap["product_sub_type"]=param.product_sub_type;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	};


	/**
	 * @Author:龙沅文
	 * @Title 基金产品判断是否是首次购买(1001611)
	 * @param fund_account 资金账号
	 * @param product_id 产品编号

	 */
	mobileService.isFirstBuyFund = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001611";
		paraMap["product_id"] = param.product_id;
		paraMap["fund_account"] = param.fund_account;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};


	/**
	 * @Author:龙沅文
	 * @Title 加密(1000000)
	 */
	mobileService.getRSAKey = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000000";
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:lzy
	 * @param :user_id 用户编号
	 * @param :product_id 产品编号
	 * @Title 获取是否需要密码
	 */
	mobileService.queryPwd = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001112";
		paraMap["bank_no"] = param.bank_no;
		paraMap["trans_type"] = param.trans_type;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title 检测是否可以提交订单 (金融产品)
	 * @param :user_id 用户编号
	 * @param :product_id 产品编号
	 *
	 */
	mobileService.checkOrderSubmit = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000258";
		paraMap["user_id"] = param.user_id;
		paraMap["product_id"] = param.product_id;
		paraMap["trade_pwd"] = param.trade_pwd;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		paraMap["risk_type_id"] = param.risk_type_id;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title :检测是否可以提交订单 (非金融产品)(1000259)
	 * @param :user_id 用户编号
	 * @param :product_id 产品编号
	 *
	 */
	mobileService.checkOthorOrderSubmit = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000259";
		paraMap["user_id"] = param.user_id;
		paraMap["product_id"] = param.product_id;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};


	/**
	 * @Author:龙沅文
	 * @Title 服务产品购买 (1000230)
	 * @param :user_id 用户编号
	 * @param :product_id	产品编号
	 * @param :rules_id	价格规则编号
	 * @param :service_type	服务规则
	 * @param :order_quantity  数量
	 *
	 */
	mobileService.servBuy = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000230";
		paraMap["user_id"] = param.user_id;
		paraMap["product_id"] = param.product_id;
		paraMap["rules_id"] = param.rules_id;
		paraMap["service_type"] = param.service_type;
		paraMap["order_quantity"] = param.order_quantity;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title 咨询产品购买 (1000233)
	 * @param :user_id 用户编号
	 * @param :product_id	产品编号
	 * @param :rules_id	价格规则编号
	 * @param :service_type	服务规则
	 * @param :order_quantity  数量
	 *
	 */
	mobileService.infoBuy = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000233";
		paraMap["user_id"] = param.user_id;
		paraMap["product_id"] = param.product_id;
		paraMap["rules_id"] = param.rules_id;
		paraMap["service_type"] = param.service_type;
		paraMap["order_quantity"] = param.order_quantity;
		paraMap["order_channel"] = param.order_channel;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title 非金融产品交易时间校准 (1000301)
	 * @param :data 时间
	 */
	mobileService.dealTimeSyn = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000301";
		paraMap["data"] = param.data;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:龙沅文
	 * @Title 填写电话邮箱 (1000253)
	 * @param order_id 订单编号
	 * @param user_mail 邮箱
	 * @param mobile_phone 电话
	 */
	mobileService.mobile_phoneOrUser_mailInfo = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000253";
		paraMap["order_id"] = param.order_id;
		paraMap["user_mail"] = param.user_mail;
		paraMap["mobile_phone"] = param.mobile_phone;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * @Title 查询基金产品(基金对比时用) (1000330)
	 * @param product_code 产品编号
	 * @param product_name 产品名称
	 * @param product_shelf 产品上架状态
	 */
	mobileService.queryFundList = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000330";
		paraMap["product_code"] = param.product_code;
		paraMap["product_name"] = param.product_name;
		paraMap["product_shelf"] = param.product_shelf;
		paraMap["product_sub_type"] = param.product_sub_type;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * @Title 退出登入 (1000001)
	 */
	mobileService.loginOut = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000001";
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:黎志勇
	 * @Title 基金分红 (1001602)
	 */
	mobileService.setFh = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001602";
		paraMap["fund_account"] = param.fund_account;
		paraMap["product_id"] = param.product_id;
		paraMap["product_code"] = param.product_code;
		paraMap["operation_type"] = param.operation_type;
		paraMap["fenhong_type"] = param.fenhong_type;
		paraMap["phone"] = getPhone();
		paraMap["entrust_way"] = "SJWT";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 短信验证码发送(501600)
	 * @param op_way 访问接口来源标识(0：pc,2：pad,3：手机)
	 * @param mobile_no 手机号码
	 * @param ip 客户IP地址
	 * @param mac 设备mac地址
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.getSmsCode = function (param,callback,ctrlParam)
	 {
		var paraMap = {};
		paraMap["funcNo"] = "501600";
		paraMap["op_way"] = param.op_way;
		paraMap["verify_code"] = param.verify_code;
		paraMap["mobile_no"] = param.mobile_no;
		paraMap["ip"] = param.ip;
		paraMap["mac"] = param.mac;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 };

	 /**
	 * 登录短信验证码校验(501521)
	 * @param mobile_no 手机号码
	 * @param mobile_code 手机验证码
	 * @param login_flag 登录业务标准
	 * @param callback 回调函数
	 */
	mobileService.checkSmsCode = function (param,callback,ctrlParam)
	   {
		var paraMap = {};
		paraMap["funcNo"] = "501521";
		paraMap["mobile_no"] = param.mobile_no;
		paraMap["mobile_code"] = param.mobile_code;
		paraMap["login_flag"] = param.login_flag;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	   };

	   /**
		* 手机绑定(901930)
		* @param phone 手机号码
		* @param hardsn 硬件信息
		* @param callback 回调函数
		*/
	   mobileService.bindMobile = function (param,callback,ctrlParam)
	   {
		  var paraMap = {};
		  paraMap["funcNo"] = "901930";
		  paraMap["phone"] = param.phone;
		  paraMap["hardsn"] = param.hardsn;
		  var reqParamVo = new service.ReqParamVo();
		  reqParamVo.setUrl(global.serverPath);
		  commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	   };

	   /**
		* 增加推荐人(1001901)
		* @param order_id 订单编号
		* @param referrer_name 推荐人姓名
		* @param referrer_code 推荐人代码
		* @param callback 回调函数
		*/
	   mobileService.addReferrer = function (param,callback,ctrlParam)
	   {
		  var paraMap = {};
		  paraMap["funcNo"]="1001901";
		  paraMap["order_id"]=param.order_id;
		  paraMap["referrer_name"]=param.referrer_name;
		  paraMap["referrer_code"]=param.referrer_code;
		  var reqParamVo = new service.ReqParamVo();
		  reqParamVo.setUrl(global.serverPath);
		  commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	   };

	   /**
		* 获取广告图片
		* @Author:黎志勇
		* @param group_id 组别
		* @param ad_id 广告id
		*/
	   mobileService.getAdv = function (param,callback,ctrlParam)
	   {
		  var paraMap = {};
		  paraMap["funcNo"]="1000320";
		  paraMap["group_id"] = param.group_id;
		  paraMap["ad_id"] = param.ad_id;
		  var reqParamVo = new service.ReqParamVo();
		  reqParamVo.setUrl(global.serverPath);
		  commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	   };

	   /**
	 * @Author:李智英
	 * 修改密码
	 * @param user_id 用户编号
	 * @param pwd_type 要修改的密码类型 0 交易密码 1 资金密码
	 * @param trade_pwd/fund_pwd 原密码
	 * @param new_fund_pwd/new_trade_pwd  新密码
	 * @param new_fund_pwd1/new_trade_pwd1  确认新密码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.changPwd = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		if(param.pwd_type==0){
			paraMap["funcNo"] = "1001114";
			paraMap["user_id"] = param.user_id;
			paraMap["trade_pwd"] = param.old_pwd;
			paraMap["new_trade_pwd"] = param.new1_pwd;
			paraMap["new_trade_pwd1"] = param.new2_pwd;
		}else if(param.pwd_type==1){
			paraMap["funcNo"] = "1001115";
			paraMap["user_id"] = param.user_id;
			paraMap["fund_pwd"] = param.old_pwd;
			paraMap["new_fund_pwd"] = param.new1_pwd;
			paraMap["new_fund_pwd1"] = param.new2_pwd;
		}
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	 /**
	 * @Author:张东东
	 * 修改登录密码
	 * @param user_id 用户编号
	 * @param pwd_type 要修改的密码类型 0 交易密码 1 资金密码
	 * @param trade_pwd/fund_pwd 原密码
	 * @param new_fund_pwd/new_trade_pwd  新密码
	 * @param new_fund_pwd1/new_trade_pwd1  确认新密码
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.changLoginPwd = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"]="1000217";
		paraMap["user_id"] = param.user_id;
		paraMap["pwd_value_befor"] = param.old_pwd;
		paraMap["pwd_value_after"]=param.new1_pwd;
		paraMap["pwd_value_after1"]=param.new2_pwd;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	 //--------商城开户，完善资料----
	/**
	 * 功能:商城 设置密码
	 * funcNo 1000040
	 * 入参: trd_pwd: 支付密码
	 *      fund_pwd: 提现密码
	 */
	mobileService.setPwd = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000040";
		paraMap["trd_pwd"] = param.trd_pwd;
		paraMap["fund_pwd"] = param.fund_pwd;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

		/**
	 * funcNo 1000371
	 * 功能:开户流程，查询用户个人资料，对状态进行判断
	 * 入参: user_id: 用户id
	 */
	mobileService.findUserInfo = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000371";
		paraMap["user_id"] = param.user_id;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
		/**
	 * funcNo 1000373
	 * 功能:查询风险测评答案
	 * 入参: user_id: 用户id
	 */
	mobileService.findRiskAnswer = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000373";
		paraMap["user_id"] = param.user_id;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	//年费表  曾颖
	mobileService.operateAnnualfee = function(param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1002028";
		paraMap["type"] = param.type;  // 增删改查
		paraMap["userid"] = param.userid;
		paraMap["khh"] = param.khh;
		paraMap["orderId"] = param.orderId;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.mallServerPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * funcNo 1000372
	 * 功能:保存风险测评答案
	 * 入参: user_id: 用户id
	 */
	mobileService.saveRisk = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000372";
		paraMap["user_id"] = param.user_id;
		paraMap["paper_answer"] = param.paper_answer;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * funcNo 1000375
	 * 功能:确认提交个人资料
	 * 入参: user_id: 用户id
	 */
	mobileService.commitUserInfo = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000375";
		paraMap["user_id"] = param.user_id;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * funcNo 1000377
	 * 功能:确认提交个人资料
	 * 入参: user_id: 用户id
	 */
	mobileService.getkhBank = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000377";
		paraMap["user_id"] = param.user_id;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * funcNo 1000380
	 * 功能:忘记密码时，重置密码，判断是否需要输入身份证，
	 * 及输入验证
	 * 入参: mobile_phone : 输入手机号
	 *      card_no： 身份证号码 验证身份证是传入
	 *      type : "1"
	 */
	mobileService.checkCardNo = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000380";
		paraMap["mobile_phone"] = param.mobile_phone;
		paraMap["card_no"] = param.card_no;
		paraMap["type"] = param.type;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * 查询用户银行卡资金
	 * @param {Object} callBackFunc
	 * @param {Object} fund_account
	 * @param {Object} bank_no
	 * @param {Object} bank_pwd
	 * @param {Object} trade_pwd
	 * @memberOf {TypeName}
	 */
	mobileService.queryBank = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000353";
		paraMap["bank_no"] = param.bank_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["bank_pwd"] = param.bank_pwd;
		paraMap["trade_pwd"] = param.trade_pwd;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

	}

	/**
	 * funcNo:1001800
	 * 功能:存储用户信息，并且开otc开客户号
	 * @param user_id 用户编号
	 * @param identity_type 证件类型
	 * @param identity_num 证件号码
	 * @param user_name 姓名
	 */
	mobileService.saveUserInfo = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001800";
		paraMap["user_id"] = param.user_id;
		paraMap["identity_type"] = param.identity_type;
		paraMap["identity_num"] = param.identity_num;
		paraMap["user_name"] = param.user_name;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}
	/**
	 * funcNo:1001801
	 * 功能:开资产账号
	 * @param user_id 用户编号
	 */
	mobileService.openingCapitalAccount = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001801";
		paraMap["user_id"] = param.user_id;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * funcNo:1001807
	 * 功能：查询手机号状态
	 * @param mobile_phone 手机号
	 */
	mobileService.queryMobilePhoneState = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001807";
		paraMap["mobile_phone"] = param.mobile_phone;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * funcNo:1001114
	 * 功能:设置密码
	 * @param user_id 用户编号
	 * @param trade_pwd 交易密码
	 * @param new_trade_pwd 新交易密码
	 * @param new_trade_pwd1 确认密码
	 * @param oper_type 操作类型
	 */
	mobileService.setPassw = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001114";
		paraMap["user_id"] = param.user_id;
		paraMap["trade_pwd"] = param.trade_pwd;
		paraMap["new_trade_pwd"] = param.new_trade_pwd;
		paraMap["new_trade_pwd1"] = param.new_trade_pwd1;
		paraMap["oper_type"] = param.oper_type;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * funcNo:1001802
	 * 功能：签电子协议
	 * @param user_id 用户编号
	 */
	mobileService.signZhAgreement = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001802";
		paraMap["user_id"] = param.user_id;
		paraMap["trade_pwd"] = param.trade_pwd;
		paraMap["new_trade_pwd"] = param.new_trade_pwd;
		paraMap["new_trade_pwd1"] = param.new_trade_pwd1;
		paraMap["oper_type"] = param.oper_type;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}
	/**
	 * funcNo:1001803
	 * 功能:查询支持的银行
	 */
	mobileService.querySupportBank = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001803";

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * funcNo:1001804
	 * 功能:申请开通支付账号
	 */
	mobileService.applyPaymentAccount = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001804";
		paraMap["user_id"] = param.user_id;
		paraMap["bank_no"] = param.bank_no;
		paraMap["bank_account"] = param.bank_account;
		paraMap["bank_mobile"] = param.bank_mobile;
		paraMap["money_type"] = param.money_type;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * funcNo:1001805
	 * 功能：同步支付账号到OTC
	 */
	mobileService.synchronousPaymentAccount = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001805";
		paraMap["user_id"] = param.user_id;
		paraMap["bank_no"] = param.bank_no;
		paraMap["bank_account"] = param.bank_account;
		paraMap["pay_account"] = param.pay_account;
		paraMap["pay_way"] = param.pay_way;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * funcNo:1001806
	 * 功能：同步登记账号和交易账号到OTC
	 */
	mobileService.simultRegTraAccount = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001806";
		paraMap["user_id"] = param.user_id;
		paraMap["bank_no"] = param.bank_no;
		paraMap["bank_account"] = param.bank_account;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * funcNo:1001808
	 * 功能：查询支付账号、绑定的银行卡
	 */
	mobileService.queryThePaymentAccount = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001808";
		paraMap["user_id"] = param.user_id;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * funcNo:1000203
	 * 功能：查询用户信息
	 */
	mobileService.queryUserInfo = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000203";
		paraMap["user_id"] = param.user_id;
		paraMap["account_name"] = param.account_name;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * funcNo:1001909
	 */
	mobileService.queryOrderInfo = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001909";
		paraMap["user_id"] = param.user_id;
		paraMap["flag"] = param.flag;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * funcNo:1001910
	 */
	mobileService.queryAccount = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001910";
		paraMap["user_id"] = param.user_id;
		paraMap["loginFlag"] = param.loginFlag;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}
	/**
	 * @Author : 柴登峰
	 * 功能 ： 记录分享次数
	 * funcNo : 1000253
	 * @param user_id 用户id
	 * @param shareType 分享平台
	 * @param callback 回调函数
	 */
	mobileService.recordShare = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1000253";
		paraMap["user_id"] = param.user_id;
		paraMap["shareType"] = param.shareType;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}
	/**
	 * @Author : 柴登峰
	 * 功能 ： 绑定账户(OTC和手机账户)
	 * funcNo : 1001957
	 * @param user_id 用户id
	 * @param shareType 分享平台
	 * @param callback 回调函数
	 */
	mobileService.bindOtcFinanAccount = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001957";
		paraMap["phoneNo"] = param.phoneNo;
		paraMap["bzjClientNo"] = param.bzjClientNo;
		paraMap["trade_pwd"] = param.trade_pwd;
		paraMap["type"] = param.type;
		paraMap["source"] = param.source;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * @Author : 柴登峰
	 * 功能 ： 判断是否要选择支付方式(OTC和手机账户)
	 * funcNo : 1001958
	 * @param user_id 用户id
	 * @param shareType 分享平台
	 * @param callback 回调函数
	 */
	mobileService.selectPayMethod = function (param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "1001958";
		paraMap["phoneNo"] = param.phoneNo;
		paraMap["bzjClientNo"] = param.bzjClientNo;
		paraMap["userId"] = param.user_id;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}
	 /********************************应用接口结束********************************/

	/**********************资金账号应用接口开始 曾颖*****************************/

	/**
	 * 功能:查询用户的资金
	 * 入参: callBackFunc: 回调函数
	 *       fund_account：资金账号
	 */
	mobileService.queryAccountFunds = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1004234";
		paraMap["fid_khh"] = param.fid_khh;
		paraMap["fid_exflg"]= param.fid_exflg;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 功能:检查是否开户
	 * 入参: callBackFunc: 回调函数
	 *       fund_account：资金账号
	 */
	mobileService.checkFunds = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1001913";
		paraMap["user_id"] = param.user_id;
		paraMap["product_id"]= param.product_id;
		paraMap["khh"]= param.khh;
		paraMap["tadm"]= param.tadm;
		paraMap["source"]= param.source;
		paraMap["tot_price"]= param.tot_price;
		paraMap["business_type"]= param.business_type;
		paraMap["trade_pwd"]= param.trade_pwd;
		paraMap["type"]= param.type;
		paraMap["risk_level"]= param.risk_level;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 功能:修改密码调用柜台
	 */
	mobileService.updateCounterPwd = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1004232";
		paraMap["fid_khh"] = param.fid_khh;
		 paraMap["fid_mm"] = param.fid_mm;
		 paraMap["fid_newmm"] = param.fid_newmm;
		 paraMap["fid_jmlx"] = param.fid_jmlx;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 功能:修改密码调用商城bus
	 */
	mobileService.updateMallPwd = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1001911";
		paraMap["user_id"] = param.user_id;
		 paraMap["khh"] = param.khh;
		 paraMap["trade_pwd"] = param.trade_pwd;
		 paraMap["new_trade_pwd"] = param.new_trade_pwd;
		 paraMap["new_trade_pwd1"] = param.new_trade_pwd1;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 功能:提交风险测评答案(资金账号)
	 */
	mobileService.submitTest = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "600005";
		paraMap["fid_khh"] = param.FID_KHH;
		 paraMap["fid_wjhm"] = param.FID_WJHM;
		 paraMap["fid_zjlb"] = param.FID_ZJLB;
		 paraMap["fid_zjbh"] = param.FID_ZJBH;
		 paraMap["fid_khxm"] = param.FID_KHXM;
		 paraMap["fid_tmda"] = param.FID_TMDA;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:柴登峰
	 * 功能:检查是否要风险测评和开户(OTC)
	 * funcNo : 1001951
	 * @param user_id 用户ID
	 * @param khh 客户号
	 * @param tadm 机构代码 ZZ
	 * @param risk_level 风险等级
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.checkRiskAssessment = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1001951";
		paraMap["user_id"] = param.user_id;
		 paraMap["khh"] = param.khh;
		 paraMap["tadm"] = param.tadm;
		 paraMap["risk_level"] = param.risk_level;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:柴登峰
	 * 功能:风险测评(OTC)
	 * funcNo : 1001952
	 * @param risk_level 风险等级
	 * @param isCp 是否需要测评 1需要0不需要
	 * @param isKh 是否需要开户 1需要0不需要
	 * @param khh 客户号
	 * @param wjhm 问卷编号 13
	 * @param zjlb 证件类型 0
	 * @param zjbh 证件号码
	 * @param khxm 客户姓名
	 * @param tmda 测评答案
	 * @param fxjg 发行机构
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.submitAns = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1001952";
		paraMap["risk_level"] = param.risk_level;
		 paraMap["isCp"] = param.isCp;
		 paraMap["isKh"] = param.isKh;
		 paraMap["khh"] = param.khh;
		 paraMap["wjhm"] = param.wjhm;
		 paraMap["zjlb"] = param.zjlb;
		 paraMap["zjbh"] = param.zjbh;
		 paraMap["khxm"] = param.khxm;
		 paraMap["tmda"] = param.tmda;
		 paraMap["fxjg"] = param.fxjg;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:柴登峰
	 * 功能:下单(OTC)
	 * funcNo : 1001953
	 * @param user_id 用户ID
	 * @param product_id 产品ID
	 * @param khh 客户号
	 * @param trade_pwd 交易密码
	 * @param source 获取来源  1. 表示 保证金  2.表示理财户   默认 表示保证金
	 * @param tot_price 购买金额
	 * @param business_type
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.placeOrder = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1001953";
		paraMap["user_id"] = param.user_id;
		 paraMap["product_id"] = param.product_id;
		 paraMap["khh"] = param.khh;
		 paraMap["trade_pwd"] = param.trade_pwd;
		 paraMap["source"] = param.source;
		 paraMap["tot_price"] = param.tot_price;
		 paraMap["business_type"] = param.business_type;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:柴登峰
	 * 功能 : 查询客户号下所有资金账户和银行卡
	 * funcNo : 1004234
	 * @param fid_khh 客户号
	 * @param fid_exflg 扩展信息 1
	 * @param fid_bz 币种 RMB
	 * @param callback 回调函数
	 * @param isLastReq 是否最后一次请求
	 * @param isShowWait 是否显示等待层
	 */
	mobileService.queryAccountBankcard = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1004234";
		paraMap["fid_khh"] = param.fid_khh;
		paraMap["fid_exflg"] = param.fid_exflg;
		paraMap["fid_bz"] = param.fid_bz;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:柴登峰
	 * 功能 : 银证转账(区分转账类型)
	 * @param khh 客户号
	 * @param fid_zjzh 资金账号
	 * @param fid_bz 币种
	 * @param fid_yhzh 银行卡
	 * @param fid_yhdm 银行类型
	 * @param fid_zzje 转账金额
	 * @param fid_wbzhmm 密码(银行密码  资金密码)
	 * @param fid_jmlx 加密类型 0
	 */
	mobileService.bankCertifiTransfer = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = param.funcNo;
		paraMap["khh"] = param.fid_khh;
		paraMap["fid_zjzh"] = param.fid_zjzh;
		paraMap["fid_bz"] = param.fid_bz;
		paraMap["fid_yhzh"] = param.fid_yhzh;
		paraMap["fid_yhdm"] = param.fid_yhdm;
		paraMap["fid_zzje"] = param.fid_zzje;
		paraMap["fid_wbzhmm"] = param.fid_wbzhmm;
		paraMap["fid_jmlx"] = param.fid_jmlx;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:柴登峰
	 * 功能 : 转账查询
	 * @param FID_KHH 客户号
	 */
	mobileService.transferQuery = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1004237";
		paraMap["FID_KHH"] = param.fid_khh;
		paraMap["page"] = param.page;
		paraMap["numPerPage"] = param.numPerPage;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:柴登峰
	 * 功能 : 查询银行卡信息
	 * @param user_id 用户ID
	 */
	mobileService.queryBankCardInfo = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1001956";
		paraMap["user_id"] = param.user_id;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * @Author:柴登峰
	 * 功能 : 获取资金账号信息
	 * @param fid_khh 客户号
	 * @param fid_exflg 扩展信息
	 * @param callback 回调函数
	 */
	mobileService.getOTCInfo = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "1004235";
		paraMap["fid_khh"] = param.fid_khh;
		paraMap["fid_exflg"] = param.fid_exflg;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};






	 /********************************云柜台开始********************************/

	 /**
	 * 云柜台登陆接口
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.login = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1000";
		paraMap["login_id"] = param.login_id;
		paraMap["identity_num"] = param.identity_num;
		paraMap["pwd_type"] = param.pwd_type;
		paraMap["pwd_value"] = param.pwd_value;
		paraMap["login_uid"] = param.login_uid;
		paraMap["login_type"] = param.login_type;
		paraMap["op_source"] = "3";
		
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 云柜台同步用户交易帐号
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.syncTradeAccount = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;
		paraMap["client_id"] = param.client_id
		
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 港股通|获取港股通需要判断的账户条件
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getGgtAuthority = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004200";
		paraMap["user_id"] = param.user_id;
		paraMap["fundid"] = param.fundid;
		paraMap["isbind"] = param.isbind;
		
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 港股通|获取港股通业务数据
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getGgtInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004201";
		paraMap["user_id"] = param.user_id;
        paraMap["entrance"] = param.entrance;    //入口
		//paraMap["trdaccount"] = param.trdaccount;
		
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 港股通|获取风险评测结果
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getSurveyInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004196";
		paraMap["user_id"] = param.user_id;
		paraMap["fundid"] = param.fundid;
		
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 港股通|获取风险评测结果
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getSurveyQuestion = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004138";
		paraMap["user_id"] = param.user_id;
		paraMap["subject_type"] = param.subject_type;
		paraMap["business_code"] = param.business_code;
		paraMap["business_id"] = param.business_id;
		
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 通用|获取电子协议
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getSign = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004178";
		paraMap["agree_name"] = param.category_englishname;
		paraMap["type_code"] = param.category_no;
		paraMap["agree_no"] = param.econtract_no;
		
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 通用|获取电子协议内容
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getProtocolInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004179";
		paraMap["version"] = param.version;
		paraMap["agree_no"] = param.agree_no;
		
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 港股通|验签，修改签名标识状态
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.checkSign = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004206";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;
		paraMap["jsondata"] = param.jsondata;
		paraMap["macaddr"] = param.macaddr;
		paraMap["ipaddr"] = param.ipaddr;
		paraMap["checksign"] = param.checksign;
		paraMap["sign_source_flag"] = param.sign_source_flag;
		
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 港股通|获取业务办理过程中的所有步骤的数据
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getGgtAllInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004207";
		paraMap["user_id"] = param.user_id;
        paraMap["entrance"] = param.entrance;    //入口
		//paraMap["trdaccount"] = param.trdaccount;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 港股通|查询信用资产
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getNetInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004405";
		paraMap["user_id"] = param.user_id;
		paraMap["fundid"] = param.fundid;
		paraMap["password"] = param.password;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 港股通|提交问卷
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.submitTestAnswer = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004139";
		paraMap["user_id"] = param.user_id;
		paraMap["subject_type"] = param.subject_type;
		paraMap["answerStr"] = param.answerStr;
		paraMap["need_third"] = param.need_third;
		paraMap["question_source"] = param.question_source;
		paraMap["sub_id"] = param.sub_id;
		paraMap["fundid"] = param.fundid;
		paraMap["business_code"] = param.business_code;
		paraMap["business_id"] = param.business_id;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 通用|发送短信
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.sendSmsCode = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004181";
		paraMap["user_id"] = param.user_id;
		paraMap["mobile_no"] = param.mobile_no;
		paraMap["sms_type"] = param.sms_type;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 通用|短信验证
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.checkSmsCode = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004191";
		paraMap["mobile_code"] = param.mobile_code;
		paraMap["mobile"] = param.mobile;
		paraMap["sms_type"] = param.sms_type;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 用户体系|短信修改手机号码
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.submitMobileNo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1007";
		paraMap["user_id"] = param.user_id;
		paraMap["mobile_code"] = param.mobile_code;
		paraMap["old_mobile"] = param.old_mobile;
		paraMap["new_mobile"] = param.new_mobile;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 创业板|获取深A和创业板权限开通数据
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getCybInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004020";
		paraMap["user_id"] = param.user_id;
		paraMap["isbind"] = param.isbind;
		paraMap["fundid"] = param.fundid;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 创业板|查询创业板转签办理状态
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getCybStatus = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004021";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 创业板|修改“是否需要创业板转签”标识
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.alterCybSign = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004022";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 创业板|提交创业板转签请求
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.submitCyb = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004023";
		paraMap["user_id"] = param.user_id;
		paraMap["name"] = param.name;
		paraMap["mobile_no"] = param.mobile_no;
		paraMap["relation"] = param.relation;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 云柜台|根据资金账户获取绑定的银行卡
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getBankList = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004134";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;
		paraMap["flag_status"] = param.flag_status;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 云柜台|根据资金账户获取绑定的银行卡
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.getAllBankList = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004135";
		paraMap["business_code"] = param.business_code;
		paraMap["bindtype"] = param.bindtype;
		paraMap["ispwd"] = param.ispwd;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	 
	 /**
	 * 云柜台|将银行卡和资金账号绑定
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.bindBank = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004136";
		paraMap["user_id"] = param.user_id;
		paraMap["backCardId"] = param.backCardId;
		paraMap["cardNo"] = param.cardNo;
		paraMap["cardPassword"] = param.cardPassword;
		paraMap["zj_account"] = param.zj_account;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }
	 
	 /**
	 * 云柜台|电子协议签署验签
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.checkSignProtocol = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004185";
		paraMap["user_id"] = param.user_id;
		paraMap["jsondata"] = param.jsondata;
		paraMap["macaddr"] = param.macaddr;
		paraMap["ipaddr"] = param.ipaddr;
		paraMap["checksign"] = param.checksign;
		paraMap["business_code"] = param.business_code;
		paraMap["business_item"] = param.business_item;
		paraMap["sign_source_flag"] = param.sign_source_flag;
		paraMap["certType"] = param.certType;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }
	 
	 /**
	 * 云柜台|三方存管-充值/提现
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.handleMoney = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004149";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;
		paraMap["bankNum"] = param.bankNum;
		paraMap["money"] = param.money;
		paraMap["password"] = param.password;
		paraMap["flag"] = param.flag;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }
	 
	 /**
	 * 云柜台|获取委托方式
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.getDelegate = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004151";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;
	
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }

	 /**
	 * 云柜台|修改委托方式
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.editDelegate = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004161";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;
		paraMap["change_type"] = param.change_type;
		paraMap["entrust_code"] = param.entrust_code;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }

	 /**
	 * 云柜台|获取三方存管、风险测评、证件照片、委托方式相关信息
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.getRsikInfo = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004163";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }

	 /**
	 * 港股通|添加港股通跑批任务
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.openAccount = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004205";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;

		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

    /**
     * 港股通|选择需要开通港股通的交易帐号
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.getStockHolder = function(param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "1004208";
        paraMap["user_id"] = param.user_id;
        console.log("yangrui"+param.trdaccount);
        paraMap["trdaccount"] = param.trdaccount;    //入口

        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }

    /**
     * 港股通|国债逆回购权限办理数据获取
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.getGznhg = function(param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "1004432";
        paraMap["user_id"] = param.user_id;

        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }

    /**
     * 港股通|修改问卷流程状态
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.xiuGaijuan = function(param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "1004202";
        paraMap["user_id"] = param.user_id;
        paraMap["survey_type"] = param.survey_type;

        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }

    /**
     * 港股通|选择需要开通港股通的交易帐号
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.getGuoZh = function(param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "1004435";
        paraMap["user_id"] = param.user_id;
        console.log("yangrui"+param.trdaccount);
        paraMap["trdaccount"] = param.trdaccount;    //入口
        paraMap["jsondata"] = param.jsondata;    //入口
        paraMap["checksign"] = param.checksign;    //入口
        paraMap["certType"] = param.certType;    //入口

        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
    
    /**
     * 创业板|提交选择的深A账户
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.submitSzaAccount = function(param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "1004029";
        paraMap["user_id"] = param.user_id;
        paraMap["trdaccount"] = param.trdaccount;    //入口

        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }


	 /********************************云柜台结束********************************/

	 /*******************************小贷开始**********************************/
	 /**
     * 功能:验证登录(610002)
     *@param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.CheckFunction = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "600000";
        paraMap["pageCode"] = param.pageCode;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
	
    /**
     * 功能: 查询提交的订单信息
     *@param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.QueryOrderInfo = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "600004";
        paraMap["order_id"] = param.order_id;
        paraMap["code"] = param.code;
        paraMap["pageCode"] = param.pageCode;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
	/**
     * 功能:验证登录(610002)
     *@param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.Login = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610002";
        paraMap["login_id"] = param.login_id;
        paraMap["password"] = param.password;
        paraMap["ticket"] = param.ticket;
        paraMap["begin_index"] = param.begin_index;
        paraMap["op_source"] = global.op_source;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
     *功能: 查询协议内容(610003)
	 */
	mobileService.QuerySignAgreement = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610003";
        paraMap["type_ename"] = param.type_ename;
        paraMap["version"] = param.version;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
     * 功能: 签署协议(610004)
	 */
	mobileService.SignAgreement = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610046";
        paraMap["type_enameStr"] = param.type_ename;
        paraMap["versionStr"] = param.version;
        paraMap["op_source"] = param.op_source;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
     * 功能: 查询风测及征信问卷题目(610005)
     *@param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.QueryQuestion = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610005";
        paraMap["sub_id"] = param.sub_id;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
     * 功能: 查询测评分数(610006)
     *@param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.QueryRiskInfo = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610006";
        paraMap["answer_result"] = param.answer_result;
        paraMap["op_mode"] = "query";
        paraMap["xdt_myLoan_limitMoney"] = param.xdt_myLoan_limitMoney;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
     * 功能: 查询测评分数(610006)
     *@param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.RiskAssessment = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610006";
        paraMap["answer_result"] = param.answer_result;
        paraMap["flag"] = param.flag;
        paraMap["xdt_myLoan_limitMoney"] = param.xdt_myLoan_limitMoney;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
     * 功能:添加用户授信额度(610008)
     *@param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.AddCreditInfo = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610008";
        paraMap["answer_result"] = param.answer_result;
        paraMap["xdt_myLoan_limitMoney"] = param.xdt_myLoan_limitMoney;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
     * 功能:授信额度(610009)
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.UserCredit = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610009";
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
	
    /**
	 * 借款 获取可质押持仓
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.CanPledgePositions = function(param,callback,ctrlParam)
    {
	    var paraMap = {};
	    paraMap["funcNo"] = "610010";
    paraMap["useFlag"] = param.useFlag;
	    if(!param.tag_type)
			param.tag_type = "all";
	    paraMap["tag_type"] = param.tag_type;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
     * 功能: 提交订单
     * 入参: callBackFunc: 回调函数
     *      borrow_amount：借款金额
     *      tag_type：融资池类型
     *      be_used：资金用途
     *      days：产品期限
     *      stock_list：质押股票列表
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.AddOrder = function(param,callback,ctrlParam)
    {
	    var paraMap = {};
		paraMap["funcNo"] = "600003";
		paraMap["type"] = param.type;
		paraMap["orderInfo"] = param.orderInfoJson;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
	/**
	 * 功能:添加一个标识变量到session
	 * 入参: callBackFunc: 回调函数
	 *      type: read:读取   save:添加
	 *      flagStr：标识变量 1.初始交易  2.提前购回 3.延期购回 4.补充质押
	 */
    mobileService.saveIdentifier = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "610034";
		paraMap["type"] = param.type;
		paraMap["flagStr"] = param.flagStr;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 功能:保存或查询合约号(610035)[保存合约号到Session]
	 * 入参: callBackFunc: 回调函数
	 *      
	 */
    mobileService.saveSuppleOrderInfo = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "610029";
		paraMap["type"] = param.type;
		paraMap["suppleOrderInfo"] = param.suppleOrderInfo;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 功能: 获取交易日(610013)
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.GetTradeDate = function(param,callback,ctrlParam)
    {
	    var paraMap = {};
	    paraMap["funcNo"] = "610013";
		paraMap["days"] = param.days;
		paraMap["date"] = param.date;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
	
    /**
	 * 借款 获取借款产品
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.QueryProductInfo = function(param,callback,ctrlParam)
    {
	    var paraMap = {};
		paraMap["funcNo"] = "610015";
		paraMap["tag_type"] = param.tag_type;
		paraMap["days"] = param.days;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
	 * 借款 获取借款用途
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.QueryUseMode = function(param,callback,ctrlParam)
    {
	    var paraMap = {};
		paraMap["funcNo"] = "610016";
		paraMap["tag_type"] = param.tag_type;
		paraMap["mode_code"] = param.mode_code;
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
	 * 资产信息
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.UserMoneyInfo = function(param,callback,ctrlParam)
    {
	    var paraMap = {};
		paraMap["funcNo"] = "610017";
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
    /**
	 * 查询合约
	 * @param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.QueryOrder = function(param,callback,ctrlParam)
	{
	    var paraMap = {};
	    paraMap["funcNo"] = "610018";
	    paraMap["page"] = param.page;
	    paraMap["size"] = param.size;
	    paraMap["order_status"] = param.order_status;
		paraMap["isRepay"] = param.isRepay;
		paraMap["order_no"] = param.order_no;
		paraMap["type"] = param.type;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 还款
	 * @param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.RepayMoney = function(param,callback,ctrlParam)
	{
	    var paraMap = {};
	    paraMap["funcNo"] = "610020";
		paraMap["order_id"] = param.order_id;
		paraMap["sublist"] = param.sublist;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 功能: 申请延期(610021)
	 * @param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.ApplyDelay = function(param,callback,ctrlParam)
	{
	    var paraMap = {};
	    paraMap["funcNo"] = "610021";
	    paraMap["order_id"] = param.order_id;
		paraMap["delay_days"] = param.delay_days;
		paraMap["delay_rate"] = param.delay_rate;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 获取对应order_id的合约还款信息
	 * @param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.FindRepayInfo = function(param,callback,ctrlParam)
	{
		var paraMap = {};
		paraMap["funcNo"] = "610041";
		paraMap["order_id"] = param.order_id;
		paraMap["contract_ids"] =param.contract_ids;
		var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 查询历史委托
	 * @param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.GetShAndSzzz = function(param,callback,ctrlParam)
	{
	    var paraMap = {};
	    paraMap["funcNo"] = "610045";
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 获取借款期限
	 * @param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.GetLoanTimeInfo = function(param,callback,ctrlParam)
	{
	    var paraMap = {};
	    paraMap["funcNo"] = "610048";
		paraMap["tag_type"] = param.tag_type;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 提交订单
	 * @param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.SubmitOrder = function(param,callback,ctrlParam)
	{
	    var paraMap = {};
	    paraMap["funcNo"] = "610014";
	    paraMap["tag_type"] = param.tag_type;
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 根据session中保存的订单编号查询订单信息
	 * @param param json格式入参 begin_index索引,sort,size,jsbz交收标志 1 已经购回  0 未购回,start_date,end_date
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.ReadOrder = function(param,callback,ctrlParam)
	{
	    var paraMap = {};
	    paraMap["funcNo"] = "610056";
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * 添加子订单 --补充质押
	 */
	mobileService.saveSubOrder = function(param,callback,ctrlParam)
	{
	    var paraMap = {};
	    paraMap["funcNo"] = "610058";
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * 查询即将到期
	 */
	mobileService.GetWarnRepay = function(param,callback,ctrlParam)
	{
	    var paraMap = {};
	    paraMap["funcNo"] = "610065";
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 查询二级资金
	 */
	mobileService.SecondMoney = function(param,callback,ctrlParam)
	{
	    var paraMap = {};
	    paraMap["funcNo"] = "610073";
	    var reqParamVo = new service.ReqParamVo();
	    reqParamVo.setUrl(global.serverPath);
	    commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
    /**
     * 功能: 查询还款合约信息(610018)
     * 入参: callBackFunc: 回调函数
     *        page :当前页
     *        size :每页数量
     *        order_status :合约状态
     */
    mobileService.getOrderInfo = function (param,callback,ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610018";
        paraMap["page"] = "1";
        paraMap["size"] = "3000";
//        paraMap["isRepay"] = param.isRepay;
//        paraMap["order_no"] = param.orderNo;
        paraMap["op_source"] = global.op_source;
        var reqParamVo = new service.ReqParamVo();
//        reqParamVo.setIsAsync(false);//设置同步模式
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
    };
    /**
     * 功能: 查询要还款的订单信息
     * 入参: callBackFunc: 回调函数
     *      order_id：订单编号
     *      code:验签的key
     */
    mobileService.getRepOrderInfo = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "600007";
        paraMap["order_no"] = param.order_no;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
    /*
     *用户还款
     */
    mobileService.repayMoney = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610020";
        paraMap["contract_id"] = param.contract_id;
        paraMap["op_source"] = global.op_source;
        paraMap["pwd"]=param.pwd;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setIsAsync(false);//设置同步模式
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
    /**
     * 还款延期数据
     * @param callBackFunc
     * @param curPage
     * @param pageSize
     * @param subOrderId
     * @param realSubOrderId
     */
    mobileService.findRepayPageInfo = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610054";
        paraMap["curPage"] = "1";
        paraMap["pageSize"] = "1";
        paraMap["subOrderId"] = param.subOrderId;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setIsAsync(false);//设置同步模式
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
    /*
     * 延期申请
     */
    mobileService.toDelay = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610063";
        paraMap["contract_id"] = param.contract_id;
        paraMap["pwd"] = param.pwd;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setIsAsync(false);//设置同步模式
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, true);
    };
    
    mobileService.findSubOrder = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610044";
		paraMap["tag_type"] =param.tag_type ;
		paraMap["exchange_type"] = param.exchange_type;
		paraMap["stock_code"] =param.stock_code;
 		paraMap["warnLineMoney"] = param.warnLineMoney;
		paraMap["pledge_share"] = param.pledge_share;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc);
    };
  //补充质押
    mobileService.supplyStock = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610323";
        paraMap["pwd"] = param.pwd;
        paraMap["pledgeStock"] =param.pledgeStock;
        paraMap["stockList"] = param.stockList;
        paraMap["op_source"] = global.op_source;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
//查询用户个人资料
    mobileService.queryInfo = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610026";
        paraMap["pwd"] = param.user_id;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
    //获取rsakey
    mobileService.getRsaKey = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "600001";
        paraMap["op_source"] = global.op_source;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
   //查询持仓
    mobileService.getMyHolding = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610050";
        paraMap["op_source"] = global.op_source;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
   //查询可还款信息
    mobileService.getBorrowMoneyPage = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610018";
        paraMap["page"] = 1;
        paraMap["size"] = 1000;
        paraMap["current_status"] = "1";
     /*   paraMap["order_status"]="9";*/
        paraMap["is_repay"]="0";
        paraMap["op_source"] = global.op_source;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
    mobileService.getBorrowMoneyHistoryPage = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610018";
        paraMap["page"] = 1;
        paraMap["size"] = 1000;
        paraMap["current_status"] = "2";// 已还款
        paraMap["op_source"] = global.op_source;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
    
    mobileService.getBorrowMoneyTimeline = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610018";
        paraMap["page"] = 1;
        paraMap["size"] = 1000;
        /*if (param.borrowDate == "请选择借款期限") {
            param.borrowDate = "";
        }*/
        paraMap["order_no"] = param.order_no;
        paraMap["borrowDate"] = param.borrowDate;
        paraMap["startDate"] = param.startDate;
        paraMap["endDate"] = param.endDate;
        paraMap["current_status"] = "1";
        paraMap["order_status"] = param.order_status;
        paraMap["op_source"] = global.op_source;
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
    mobileService.logout = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "610074";
        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo,false);
        //this.service.invoke(reqParamVo, callBackFunc, false);
    };
	 /*******************************小贷结束*********************************/

    /********************************应用接口结束********************************/
});
