/**
 * 作者:赵成
 * 证书检测和安装通用类
 */
define(function(require, exports, module) {
	
	var appUtils = require("appUtils");
	var gconfig = require("gconfig");
	var layerUtils = require("layerUtils");
	var external = require("external");
	var certService = require("certService");
	
	/**
	 * 检测证书环境，检测用户是否申请了证书，是否安装了证书
	 * 参数：user_id：用户编号
	 *      cert_type: 证书类型   0：中登  1：自建
	 * 返回：
	 * certUsed:  true 证书可用   false  证书不可用
	 * certStatus：  证书状态， 在“证书不可用”时查看该状态
	 *               1:没有申请过证书，没有证书用户（证书id），需要视频申请
	 */
	function initCheckCert(cert_type, callback) {
		var certResult = {};
        certResult["certUsed"] = "false";
        if(cert_type == "zd") {
        	cert_type = "0";
        } else if(cert_type == "tw") {
        	cert_type = "1";
        }
		var param = {
			"user_id":appUtils.getSStorageInfo("user_id"),
			"cert_type":cert_type
		};
		var ctrlParam = {
			errorFunc: function handleTimeout(cert_type,callback) {
				layerUtils.iConfirm("请求超时，是否重新加载？", function() {
					initCheckCert(cert_type, callback) // 再次查询证书状态
				});
			},
			isLastReq:false
		}
		//检测是否申请过证书
		certService.certCheckStatus(param, function(data){
			var error_no = data.error_no;
			var error_info = data.error_info;
			var result = data.results[0]
			if(error_no == "0") {
				if(result["hascert"]=="1"){//是否申请过证书  0：否，1：是
					if(cert_type == "0") {
						cert_type = "zd";
					} else if(cert_type == "1") {
						cert_type = "tw";
					}
					//检测时候安装证书
					var existsParam = {
						"userId" : appUtils.getSStorageInfo("user_id"),
						"mediaId" : "certificate",
						"type" : cert_type,
						"funcNo" : "60000"
					};
					var result = external.callMessage(existsParam);
					var error_no = result.error_no;
					var error_info = result.error_info;
					var result = result.results[0];
					if ((error_no == "0" || error_no == "1") && result.mediaId == "") {
						installCertificate(cert_type, certResult, callback, ctrlParam); // 下载安装证书，并且显示证券账户和协议
					} else {
						//有证书,证书可用
						certResult["certUsed"] = "true";
						// 关闭等待层。。。
						layerUtils.iLoading(false);
						callback(certResult);
					}
				} else { //没有申请证书,去提交身份证的页面,然后做完视频见证,在申请证书
					certResult["certStatus"] = "1";
                    callback(certResult);
				}
			} else {
				layerUtils.iAlert(error_info, -1);
			}
		}, ctrlParam);
	}

	/**
	 * 下载证书
	 * @param callback 证书下载安装之后回调处理
	 */
	function installCertificate(cert_type, certResult, callback, ctrlParam) {
		// 下载证书，创建10位随机数
		var createKeyRandom = "1";
		for (var i = 0; i < 9; i++) {
			createKeyRandom += parseInt(Math.random() * 10) + "";
		}
		// 证书申请串，数据来源于壳子
		var pkcs10 = "",
		createKeyParam = {
			"rodam": createKeyRandom,
			"userId": appUtils.getSStorageInfo("user_id"),
			"key": "stockDelegateTradeSys",
			"funcNo": "60003"
		};
		var result = external.callMessage(createKeyParam);
		var error_no = result.error_no;
		var error_info = result.error_info;
		var result = result.results[0];
		if (error_no == "0" || error_no == "1") {
			pkcs10 = result.pkcs10;
			var param = {
				"user_id": appUtils.getSStorageInfo("user_id"),
				"pkcs10": encodeURIComponent(pkcs10)
			};
			if(cert_type == "zd") {
				//安装中等证书
				certService.zdCertInseert(param, function(data) {
					callcert(data, cert_type, certResult, callback);
				}, ctrlParam);
			} else { //自建证书
				certService.zjCertInseert(param, function(data) {
					callcert(data, cert_type, certResult, callback);
				}, ctrlParam);
			}
		} else {
			handleTimeout(cert_type, callback);
		}
	}

	/**
	 * 安装证书回调方法
	 * @param callback 证书下载安装之后回调处理
	 */
	function callcert(data, cert_type, certResult, callback) {
		var error_no = data.error_no;
		var error_info = data.error_info;
		if (error_no == "0") {
			// 获取证书的内容
			var certParam = {
				"content": data.results[0].p7cert,
				"userId": appUtils.getSStorageInfo("user_id"),
				"type": cert_type,
				"funcNo": "60004"
			};
			var result = external.callMessage(certParam);
			var error_no = result.error_no;
			var error_info = result.error_info;
			if (error_no == "0" || error_no == "1") {
				certResult["certUsed"] = "true";
				callback(certResult);
			}
		} else {
			layerUtils.iLoading(false);
			layerUtils.iAlert(data.error_info, -1);
		}
	}

	/* 处理请求超时 */
	function handleTimeout(cert_type,callback) {
		layerUtils.iConfirm("请求超时，是否重新加载？", function() {
			initCheckCert(cert_type, callback) // 再次查询证书状态
		});
	}

	var certFunc = {
		"initCheckCert" : initCheckCert
	};
	//暴露对外的接口
	module.exports = certFunc;
});
